==> dde-calendar_5.9.5.orig.tar.xz: dde-calendar-5.9.5/translations/dde-calendar-service_ca.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ca">
<context>
    <name>DAccountDataBase</name>
    <message>
        <source>Work</source>
        <translation>Feina</translation>
    </message>
    <message>
        <source>Life</source>
        <translation>Vida</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Altres</translation>
    </message>
</context>
<context>
    <name>DAlarmManager</name>
    <message>
        <source>Close</source>
        <comment>button</comment>
        <translation>Tanca</translation>
    </message>
    <message>
        <source>One day before start</source>
        <translation>Un dia abans de l&apos;inici</translation>
    </message>
    <message>
        <source>Remind me tomorrow</source>
        <translation>Recorda-m&apos;ho demà.</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation>Recorda-m&apos;ho més tard.</translation>
    </message>
    <message>
        <source>15 mins later</source>
        <translation>15 minuts més tard</translation>
    </message>
    <message>
        <source>1 hour later</source>
        <translation>1 hora més tard</translation>
    </message>
    <message>
        <source>4 hours later</source>
        <translation>4 hores més tard</translation>
    </message>
    <message>
        <source>Tomorrow</source>
        <translation>Demà</translation>
    </message>
    <message>
        <source>Schedule Reminder</source>
        <translation>Programació del recrdatori</translation>
    </message>
    <message>
        <source>%1 to %2</source>
        <translation>de %1 a %2</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Avui</translation>
    </message>
</context>
<context>
    <name>JobRemindManager</name>
    <message>
        <source>One day before start</source>
        <translation type="vanished">Un dia abans de l&apos;inici</translation>
    </message>
    <message>
        <source>Close</source>
        <comment>button</comment>
        <translation type="vanished">Tanca</translation>
    </message>
    <message>
        <source>Remind me tomorrow</source>
        <translation type="vanished">Recorda-m&apos;ho demà</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation type="vanished">Recorda-m&apos;ho més tard</translation>
    </message>
    <message>
        <source>Schedule Reminder</source>
        <translation type="vanished">Programació del recordatori</translation>
    </message>
    <message>
        <source>%1 to %2</source>
        <translation type="vanished">de %1 a %2</translation>
    </message>
    <message>
        <source>Today</source>
        <translation type="vanished">Avui</translation>
    </message>
    <message>
        <source>Tomorrow</source>
        <translation type="vanished">Demà</translation>
    </message>
</context>
</TS>

==> dde-calendar_5.9.14.orig.tar.xz: dde-calendar-5.9.14/translations/dde-calendar-service_ca.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ca">
<context>
    <name>DAccountDataBase</name>
    <message>
        <source>Work</source>
        <translation>Feina</translation>
    </message>
    <message>
        <source>Life</source>
        <translation>Vida</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Altres</translation>
    </message>
</context>
<context>
    <name>DAlarmManager</name>
    <message>
        <source>Close</source>
        <comment>button</comment>
        <translation>Tanca</translation>
    </message>
    <message>
        <source>One day before start</source>
        <translation>Un dia abans de l&apos;inici</translation>
    </message>
    <message>
        <source>Remind me tomorrow</source>
        <translation>Recorda-m&apos;ho demà.</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation>Recorda-m&apos;ho més tard.</translation>
    </message>
    <message>
        <source>15 mins later</source>
        <translation>15 minuts més tard</translation>
    </message>
    <message>
        <source>1 hour later</source>
        <translation>1 hora més tard</translation>
    </message>
    <message>
        <source>4 hours later</source>
        <translation>4 hores més tard</translation>
    </message>
    <message>
        <source>Tomorrow</source>
        <translation>Demà</translation>
    </message>
    <message>
        <source>Schedule Reminder</source>
        <translation>Programació del recrdatori</translation>
    </message>
    <message>
        <source>%1 to %2</source>
        <translation>de %1 a %2</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Avui</translation>
    </message>
</context>
<context>
    <name>Return</name>
    <message>
        <source>Today</source>
        <comment>Return</comment>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Return Today</name>
    <message>
        <source>Today</source>
        <comment>Return Today</comment>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>today</name>
    <message>
        <source>Today</source>
        <comment>Today</comment>
        <translation type="unfinished"/>
    </message>
</context>
</TS>
